
% Script calculates a forward encoding model on time domain EEG DATA
% (see Lalor 2006, 2009);


% Sophie Herbst, Feb. 2016
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%
clear all;
clc; close all;

%% Directories
% load the path where fieldtrip is located
addpath('/Users/sophie/ownCloud/MATLAB_Toolboxes/fieldtrip-20160620/'); % using the newer FT version!
addpath('/Users/sophie/ownCloud/MATLAB_Toolboxes/shadedErrorBar');
ft_defaults

% load TRF functions
addpath('/Users/sophie/ownCloud/MATLAB_Toolboxes/mTRF_1.3')

rootDir = '/Volumes/SophiesDATA/DisTime_EEGII/';
rawDir = '/Volumes/SophiesDATA/DisTime_EEGII/raw/';
preprocDir = '/Volumes/SophiesDATA/DisTime_EEGII/preproc/';

resDir =  '/Users/sophie/Documents/DATA/TRF_DisTime_EEGII/';

PicDir = '/Users/sophie/ownCloud/PROJECT_DisTime/DisTime_mTRF/MS_DisTime_TRF/Pics_MS_DisTime_TRF/MatlabOutput/';

%% Parameters

run_model = 1; % run mTRF or just load the saved data
check_plots = 0; % make single subject plots

% lags for the TRF;
tau = [-200  600];

% timevector for the lags (used for plotting)
tlags = tau(1)/1000:1/200:tau(2)/1000;
nlags = size(tlags,2);

% ridge parameter for the TRF
lambda = 4; %0.5; % 4

% epoch time-locked to cross/cue or tone
lock = 'cross';

% latency for ft_selectdata (epoching from cue)
latency =[0 3.5];

% use only trials that have minimally this foreperiod duration
minFP = 0.65;

% take DATA only from that timepoint (postcue); avoid mixing in cue-resonse
startLAT = .5;

% subjects
sbs = dir([rawDir '*.cnt']);

% define one channel for plotting
channame = 'Cz';

% colors for the plots
cond_colors = [253,184,99; 178,171,210; 94,60,153];
cond_colors = cond_colors./255;

%% load and plot the hazard Functions:

% load([rootDir filesep 'preproc_notes' filesep  'sHF4Reg_long0.mat']); % subjective (with Shadlen's smoothing factor)
% load([preprocDir filesep  'EEGII_HF4Reg_long0.mat']);
load([preprocDir filesep  'EEGII_HF4Reg_longINT.mat']);

% plot the HFs
figure; hold on;
for i_cond = 1:size(HF_time_matrix_int,2)
    subplot(3,1,i_cond);
    plot(HF_time_matrix_int(i_cond).HF_time(:,1),HF_time_matrix_int(i_cond).HF_time(:,2),...
        'color',cond_colors(i_cond,:),'LineWidth',1);
    title(['condition ' num2str(i_cond)])
    ylabel('hazard');
    ylim([0 1])
end
xlabel('time [s]');

% use only 2 HFs: from conditions 1 & 3
condHF1 = HF_time_matrix_int(1).HF_time(:,2);
condHF3 = HF_time_matrix_int(3).HF_time(:,2);

condHF3 = condHF3-condHF1;
condHF3(find(condHF3 < 0)) = 0;

condHF = [condHF1 condHF3];

if 1
% filter HFs
[b,a] = butter(6,[25/(200/2)],'low'); % 1.arg = order, 2. = cutoff-freq/(fs/2), 3. low or highpass
condHF = filtfilt(b,a,condHF); % filter twopass
end

subplot(3,1,1);hold on;
plot(HF_time_matrix_int(1).HF_time(:,1),condHF(:,1),...
    'color',cond_colors(1,:),'LineWidth',1);

subplot(3,1,3);hold on;
plot(HF_time_matrix_int(3).HF_time(:,1),condHF(:,2),...
    'color',cond_colors(i_cond,:),'LineWidth',1);

% print('-dpdf',[PicDir filesep 'EEGII_TRF_combMod_HFs.pdf'], '-painters')% PicDir filesep

%% initialize MATRICES sbs x conditions x HF

B_MAT= cell(size(sbs,1),3); % Matrix for the regression weights, sbs x conds
const_MAT = cell(size(sbs,1),3); % Matrix for the regression constant, sbs x conds
origEEG = cell(size(sbs,1),3); % Matrix for original data; does not differ between 2 HFs
STIM_MAT = cell(size(sbs,1),3); % Matrix for Stimuli (HF),sbs x conds

predEEG = cell(size(sbs,1),3,3); % Matrix for predicted EEG data
CORR_MAT = cell(size(sbs,1),3); % Matrix for correlations
CORR_IND = cell(size(sbs,1),3); % Matrix for correlation indices

FP_MAT = cell(size(sbs,1),3); % note the FPs for each trial

% Matrix for trial-averaged reg weights
avgB_MAT = NaN(numel(sbs),3,2,61,nlags);  % sbs x conds x HF x channels x lags

%% start loading DATA

if run_model
    for i_sb = 1 : size(sbs,1)
        
        % load raw DATA for each SB
        
        [dum SB] =  fileparts(sbs(i_sb).name);
        disp(['loading subject ' SB '...']);
        load([preprocDir filesep SB 'preproc_complete_' lock 'lock_HP_minphase']);
        
        DATA = DATA_clean; clear DATA_clean;
        
        plotchan = find(strcmp(DATA.label,channame));
        
        
        %% LP filter the data
        
        cfg = [];
        cfg.lpfilter = 'yes';
        cfg.lpfilttype = 'but'; %'firws';
        
        cfg.lpfilord = 6;
        
        cfg.plotfiltresp = 'no';
        cfg.lpfiltdir = 'twopass'; %'onepass-zerophase';
        
        cfg.lpfreq   = 25; %8% % low pass frequency
        cfg.lpfiltdf = 1; % transition band witdth
        
        DATA_filt = ft_preprocessing(cfg,DATA);
        
        
        % check effect of filtering
        if check_plots
            
            tmptime = DATA.time{1};
            
            cfg = [];
            DATA_avg = ft_timelockanalysis(cfg,DATA);
            DATA_filt_avg = ft_timelockanalysis(cfg,DATA_filt);
            
            tmpdat = DATA_avg.avg;
            tmpdat_filt = DATA_filt_avg.avg;
            
            figure();
            plot(tmptime,tmpdat(plotchan,:)); hold all;
            plot(tmptime,tmpdat_filt(plotchan,:));
            
            legend({'unfiltered', 'filtered'});
            title (['SB ' SB ' channel channame' ])
            
            clear DATA_avg DATA_filt_avg tmpdat tmpdat_filt
        end
        
        DATA = DATA_filt; clear DATA_filt;
        fs = round(DATA.fsample); % round because in some sbs fs = 200.00 and that causes prblms with mTRF
        
        %% select DATA at the defined latencies
        
        cfg = [];
        cfg.latency = latency;
        DATA = ft_selectdata(cfg,DATA);
        
        Tvec = DATA.time{1}; % the data time vector
        
        % for TRF only data from 500ms after cue onset will be used
        % to remove visual onset ERP
        startIX = nearest(Tvec,startLAT); % same for all trials
        % endIX is defined in each trial, as the onset of the target tone
        
        
        %% loop over conditions
        for i_cond = 1:3
            disp(['cond ' num2str(i_cond)]);
            
            
            %% prepare condition DATA
            
            clear condDATA;
            
            % select all trials from the condition and with FP >= minFP
            cfg = [];
            cfg.trials = find(DATA.trialinfo(:,1) == i_cond & DATA.trialinfo(:,3) >= minFP);
            condDATA = ft_selectdata(cfg,DATA);
            
            
            %% initialize subjects's matrix for regression weights: trials x HF x channels x lags
            
            B_MAT{i_sb,i_cond} = nan(size(condDATA.trial,2),2,61,nlags);
            const_MAT{i_sb,i_cond} = nan(size(condDATA.trial,2),2,61);
            
            STIM_MAT{i_sb,i_cond} = nan(size(condDATA.trial,2),size(condDATA.trial{1},2),2); % trials x TP x HF
            origEEG{i_sb,i_cond}  = nan(size(condDATA.trial,2),size(condDATA.trial{1},1),size(condDATA.trial{1},2)); % trials x chan x TP
            
            %% loop over trials
            for i_trial = 1:size(condDATA.trial,2)
                
                % get FP on each trial
                trialFP = condDATA.trialinfo(i_trial,3);
                ixFP = nearest(Tvec,trialFP); % find the closest sampling point
                endFP = 3.5;
                ixendFP = nearest(Tvec,endFP);
                
                % time vector for the trial DATA
                %trial_Tvec = Tvec(startIX:ixFP);
                trial_Tvec = Tvec(startIX:ixendFP);
                
                %% take the data from this trial and cut relevant times
                % trialDAT = condDATA.trial{i_trial}(:,startIX:ixFP); % and cut out the relevant time interval
                trialDAT = condDATA.trial{i_trial}(:,startIX:ixendFP); % and cut out the relevant time interval
                trialDAT(:,(ixFP-startIX)+1:end) = 0; % set EEG to 0 after probe onset
                
%                 figure;
%                 plot(Tvec,condDATA.trial{i_trial}(plotchan,:));hold all;
%                 plot(Tvec(startIX:ixendFP),trialDAT(plotchan,:));
%                 
                % cut the HF to the same lentght
                % trialHF = condHF(startIX:ixFP,:);
                trialHF = condHF(startIX:ixendFP,:);
                % plot(Tvec(startIX:ixendFP),trialHF);
                
                %% zscore both timeseries, make time 1. dimension
                
                % normalize HF
                ztrialHF1 = trialHF(:,1) ./ max(trialHF(:,1));
                ztrialHF2 = trialHF(:,2) ./ max(trialHF(:,2));
                ztrialHF = [ztrialHF1 ztrialHF2];
                clear ztrialHF1 ztrialHF2
                
                % zscore trial Data over time (uses first dimension)
                ztrialDAT = zscore(trialDAT');
                
                % reset the end to 0
                ztrialDAT((ixFP-startIX)+1:end,:) = 0; %
%                 
%                 figure;
%                 plot(trial_Tvec, ztrialHF(:,1)); hold all;
%                 plot(trial_Tvec, ztrialHF(:,2)); hold all;
%                 hline(0,'k');
%                 plot(trial_Tvec, ztrialDAT(:,plotchan));
%                 legend({'HF1','HF3', 'EEG data'});
%                 
%                 title(['Example HF and EEG DATA, 1 Trial']);
%                 
                % write DATA and stim (HF) in big matrices
%                 STIM_MAT{i_sb,i_cond}(i_trial,startIX:ixFP,:) = ztrialHF;
%                 origEEG{i_sb,i_cond}(i_trial,:,startIX:ixFP)  = ztrialDAT';
%                 
                STIM_MAT{i_sb,i_cond}(i_trial,startIX:ixendFP,:) = ztrialHF;
                origEEG{i_sb,i_cond}(i_trial,:,startIX:ixendFP)  = ztrialDAT';
                
                %% this is the TRF
                [X,T,const] =  mTRFtrain(ztrialHF,ztrialDAT,fs,0,tau(1), tau(2),lambda);
                % dir    - direction of mapping (forward==0, backward==1)
                
                % write the betas into a matrix: trial x HF x chan x lag
                B_MAT{i_sb,i_cond}(i_trial,:,:,:) = permute(X,[1,3,2]);
                const_MAT{i_sb,i_cond}(i_trial,:,:) = const;
                
                % plot single TRF
%                 figure;
%                 plot(T,squeeze(X(:,:,plotchan))); % plot single trial mTRF
%                 legend({'HF1','HF2'})
%                 hline(0, 'k');
%                 title(['TRF SB ' SB ' lambda: ' num2str(lambda) '-- cond' num2str(i_cond) ' --FP: ' num2str(trialFP)]);
%                 xlabel('TRF lag [s]')
%                 
            end
            
            % avg Bs over trials
            avgB_MAT(i_sb,i_cond,:,:,:) = squeeze(mean(B_MAT{i_sb,i_cond},1));
%             figure;
%             plot(T,squeeze(avgB_MAT(i_sb,i_cond,:,plotchan,:)));
        end
        
        %% now predict EEG data, 3x3 times:
        % for each condition, crossed with the 3 models
        for i_cond = 1:3
            
            clear condDATA;
            
            % select all trials from the condition and with FP >= minFP
            cfg = [];
            cfg.trials = find(DATA.trialinfo(:,1) == i_cond & DATA.trialinfo(:,3) >= minFP);
            condDATA = ft_selectdata(cfg,DATA);
            
            % loop over trials again, taking out each trial and trying to
            % repredict the EEG from them mean TRF of all other trials
            for i_trial = 1:size(condDATA.trial,2)
                
                % loop over models
                for pred_cond = 1:3
                    
                    if i_trial == 1 % initialize matrix of NaN
                        predEEG{i_sb,i_cond,pred_cond} = nan(size(condDATA.trial,2),size(condDATA.trial{1},1),size(condDATA.trial{1},2)); % trials x chan x TP
                    end
                    
                    % Get the model: for condition 1, take models 1, 2 and
                    % 3 and so on = 9 predicted EEG signals
                    % get all weights, dimensions are trials x chans x lags
                    B_leaveout = B_MAT{i_sb,pred_cond};
                    
                    % get mean model constant
                    const_leaveout = const_MAT{i_sb,pred_cond};
                    
                    % if model and data come from the same condition
                    % take out the actual trial
                    if i_cond == pred_cond
                        B_leaveout(i_trial,:,:,:) = [];
                        const_leaveout(i_trial,:,:) = [];
                    end
                    
                    % avg model over trials
                    B_mean_leaveout = squeeze(mean(B_leaveout,1));
                    const_mean_leaveout = squeeze(mean(const_leaveout,1));
                    
                    % prepare the data: from startIX to trialFP
                    trialFP = condDATA.trialinfo(i_trial,3);% FP on each trial
                    ixFP = nearest(Tvec,trialFP); % find the closest sampling point
                    endFP = 3.5;% condDATA.trialinfo(i_trial,3);% FP on each trial
                    ixendFP = nearest(Tvec,endFP); % find the closest sampling point
                    
                    % get the original DATA for the trial
                    ztrialDAT =  squeeze(origEEG{i_sb,i_cond}(i_trial,:,startIX:ixendFP))';
                    trial_Tvec = Tvec(startIX:ixendFP); % time vector for the trial DATA
                    
                    % cut the HF to the same interval as the EEG data
                    %  trialHF = condHF(startIX:ixFP,:);
                    trialHF = condHF(startIX:ixendFP,:);
                    
                    % normalize HF
                    ztrialHF1 = trialHF(:,1) ./ max(trialHF(:,1));
                    ztrialHF2 = trialHF(:,2) ./ max(trialHF(:,2));
                    ztrialHF = [ztrialHF1 ztrialHF2];
                    clear ztrialHF1 ztrialHF2
                    
%                   figure;
%                   plot(trial_Tvec, ztrialHF(:,1)); hold all;
%                   plot(trial_Tvec, ztrialHF(:,2)); hold all;
%                   hline(0,'k');
%                   plot(trial_Tvec, ztrialDAT(:,plotchan));
%                   legend({'HF1','HF3', 'EEG data'});
                   
                    
                    % predict the data of the trial, taking the mean data
                    % of all other trials and the mean model from all other
                    % trials
                    %[pred,rho,pVal,MSE] = mTRFpredict(stim,resp,model,Fs,dir,start,fin,const)
                    clear const M
                    
                    % model: obs x lags x chans
                    M = B_mean_leaveout;
                    s = size(M);
                    
                    % M1 = reshape(M,s(1),s(3),s(2));
                    M = permute(M,[1,3,2]);
                    
                    const = const_mean_leaveout;
                    
                    % here comes the prediction
                    [pE] = mTRFpredict(ztrialHF,ztrialDAT,M,fs,0,tau(1), tau(2),const);
                    
                    
                    % save predicted EEG (the whole length, needed for
                    % plotting later)
                    predEEG{i_sb,i_cond,pred_cond}(i_trial,:,startIX:ixendFP) = pE'; % trials x chan x TP
                    
                   
                    if check_plots & i_trial == 100
                        figure;
                        plot(trial_Tvec, ztrialHF,'k'); hold all;
                        plot(trial_Tvec, ztrialDAT(:,plotchan));
                        plot(trial_Tvec, pE(:,plotchan)');
                        legend({'HF1','HF2', 'EEG data', 'predicted EEG data'});
                        hline(0,'k');
                        %                         title(['Example HF and EEG DATA, cond ' num2str(i_cond) ' HF ' num2str(i_HF) ' --FP: ' num2str(trialFP)]);
                        % print('-dpdf',[PicDir filesep 'EEGII_TRF_predEEG_SB' num2str(i_sb) ...
                        % '_cond_' num2str(i_cond) '_HF_' num2str(i_HF) '_trial_' num2str(i_trial) '.pdf'], '-painters')% PicDir filesep
                    end
                    
                    %% correlate predicted and original EEG
                    
                    for i_chan = 1:size(predEEG{i_sb,i_cond,pred_cond},2)
                        
                        % extract time series of modelled EEG for 1 trial &
                        % channel
                       
                        % now take only the part of the EEG before the
                        % target
                        % modEEG = squeeze(predEEG{i_sb,i_cond,pred_cond}(i_trial,i_chan,:));
                        modEEG = squeeze(predEEG{i_sb,i_cond,pred_cond}(i_trial,i_chan,startIX:ixFP));
                       % modEEG = modEEG(find(~isnan(modEEG)));
                        
                        % extract time series of real EEG for 1 trial &
                        % channel
                        realEEG = squeeze(origEEG{i_sb,i_cond}(i_trial,i_chan,startIX:ixFP));
                       %  realEEG = realEEG(find(~isnan(realEEG)));
                        
                        % z-score both timeseries
                        modEEGz = zscore(modEEG);
                        realEEGz = zscore(realEEG);
                        
                        % correlate
                        [r,p] = corr(modEEGz,realEEGz);
                        
                        % Fisher z-transform the correlation
                        zr = .5.*log((1+r)./(1-r));
                        
                        % write transformed correlations into matrix
                        CORR_MAT{i_sb,i_cond,pred_cond}(i_trial,i_chan) =   zr;
                    end
                    
                end
            end
            % figure;imagesc(squeeze(predEEG{i_sb,i_cond,pred_cond}(:,1,:)))
        end
        
        
        %%
        %%
        
        
        %% plot single sb TRFs
        
        figure(i_sb);
        % plot single subject TRF at one channel
        TRF_SB = squeeze(avgB_MAT(i_sb,:,:,plotchan,:));
        for  i_HF = 1:2
            subplot(1,2,i_HF);hold on;
            for i_cond = 1:3
                plot(tlags,squeeze(TRF_SB(i_cond,i_HF,:)),'color',cond_colors(i_cond,:)); hold all;
            end
            
            %ylim([0 ,.01])
            xlabel('TRF lag [s]');
            title(['HF ' num2str(i_HF) ' TRF (lambda = ' num2str(lambda) ')-- ' channame]);
        end
        legend({'cond 1', 'cond 2', 'cond 3'})
    end
     save([resDir filesep 'RES_EEGII_TRF_pred2HF_longHFint_peakonly_lambda' num2str(lambda)],...
         'avgB_MAT','CORR_MAT','origEEG','predEEG', '-v7.3')  ;
else
    load ([resDir filesep 'RES_EEGII_TRF_pred2HF_lambda' num2str(lambda)]) ;
end


%% plot avg TRFs
% GFP over lags
 
my_lines = {'-','--'};

% compute GFP as std over channels
GFP = squeeze(std(avgB_MAT,[],4)); % dim 4 = channels

% avg over sbs and calculate SEM
avgGFP = squeeze(mean(GFP,1));
SEGFP = squeeze(std(GFP,[],1)/sqrt(numel(sbs)));

lags = tlags; % lag vector for plotting

for  i_HF = 1:2 % i_cond = 1:3
    % plot each cond
    figure('Units', 'pixels', ...
     'Position', [100 100 500 375]);
    hold on;

    for i_cond = 1:3% i_HF = 1:2
        plot(lags,squeeze(avgGFP(i_cond,i_HF,:)),'color',cond_colors(i_cond,:),...
            'LineStyle',my_lines{i_HF},'LineWidth',1.5); hold all;
    end
    legend({'cond 1', 'cond 2', 'cond 3'})
    % legend({'monotonous HF', 'peak HF'})
    
    for i_cond = 1:3 % i_HF = 1:2
        shadedErrorBar(lags,squeeze(avgGFP(i_cond,i_HF,:)),squeeze(SEGFP(i_cond,i_HF,:)),{'color',cond_colors(i_cond,:)},.5);
    end
    
    ylim([0 ,.04])
    xlim([-.1 ,.5])
    xlabel('TRF lag [s]');
    
    xlabel('TRF lag [s]');
   
    hl = hline(0,'k')
    vl = vline(0,'k')
    
    % title(['cond ' num2str(i_cond) ' TRF (lambda = ' num2str(lambda) ') : GFP']);
    title(['HF ' num2str(i_HF) ' TRF (lambda = ' num2str(lambda) ') : GFP']);
    
    
    % aesthetics
    set( gca                       , ...
        'FontName'   , 'Helvetica' ,...
        'FontSize'   , 8 );
    
    set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.02 .02] , ...
        'XMinorTick'  , 'off'      , ...
        'YMinorTick'  , 'off'      , ...
        'YGrid'       , 'off'      , ...
        'XGrid'       , 'off'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'YTick'       , -.1: .01 : .05, ...
        'LineWidth'   , .75         );
    
    % print( '-dpdf',[PicDir filesep 'EEGII_TRF_GFP_2HF_cond' num2str(i_cond) '.pdf'], '-painters')% PicDir filesep
%    print( '-dpdf',[PicDir filesep 'EEGII_TRF_GFP_2HF_HF' num2str(i_HF) '.pdf'], '-painters')% PicDir filesep

end


%% plot avg TRFs at one channel

% plot each cond

thischan = 'Cz';
plotchan = find(strcmp(DATA.label,thischan));

% compute AVG over channels
chan_TRF = squeeze(avgB_MAT(:,:,:,plotchan,:)); % dim 4 = channels

% avg over sbs and calculate SEM
avgTRF = squeeze(mean(chan_TRF,1));
seTRF = squeeze(std(chan_TRF,[],1)/sqrt(numel(sbs)));

lags = tlags; % lag vector for plotting

for i_HF = 2%1:2 %i_cond = 1:3
    
    figure('Units', 'pixels', ...
     'Position', [100 100 500 375]);
    hold on;

    % plot each cond
    
    for i_cond = 1:3% i_HF = 1:2
       
            plot(lags,squeeze(avgTRF(i_cond,i_HF,:)),'color',cond_colors(i_cond,:),...
        'LineStyle',my_lines{i_HF},'LineWidth',1.5); hold all;        
    end
    legend({'cond 1', 'cond 2', 'cond 3'})
    % legend({'monotonous HF', 'peak HF'})
    
    for i_cond = 1:3 % i_HF = 1:2
        shadedErrorBar(lags,squeeze(avgTRF(i_cond,i_HF,:)),squeeze(seTRF(i_cond,i_HF,:)),{'color',cond_colors(i_cond,:)},.5);
    end
    
    ylim([-0.05 0.05])
    xlim([-0.1 0.5])
    xlabel('TRF lag [s]');
    
    
    xlabel('TRF lag [s]');
    hl = hline(0,'k')
    vl = vline(0,'k')
    
    % title(['TRF cond ' num2str(i_cond) '(lambda=' num2str(lambda) ') ' thischan]);
    title(['TRF HF ' num2str(i_HF) '(lambda=' num2str(lambda) ') ' thischan]);
    
    % aesthetics
    set( gca                       , ...
        'FontName'   , 'Helvetica' ,...
        'FontSize'   , 8 );
    
    set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.02 .02] , ...
        'XMinorTick'  , 'off'      , ...
        'YMinorTick'  , 'off'      , ...
        'YGrid'       , 'off'      , ...
        'XGrid'       , 'off'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'YTick'       , -.1: .05 : .05, ...
        'LineWidth'   , .75         );
    
    
   %  print('-dpdf',[PicDir filesep 'EEGII_TRF_2HFs' thischan '_cond' num2str(i_cond) '.pdf'], '-painters')% PicDir filesep
  %  print('-dpdf',[PicDir filesep 'EEGII_TRF_2HFs' thischan '_HF' num2str(i_HF) '.pdf'], '-painters')% PicDir filesep

end

%% plot topos of regression weights

% avg weights over sbs
allsbs_BMAT = squeeze(mean(avgB_MAT,1)); % first dim is now cond

% lags at which to plot
plottimes =  [-0.1 0.0];% [0.2 0.3]; %
plotlag1 =  nearest(lags,plottimes(1));
plotlag2 =  nearest(lags,plottimes(2));

for i_HF = 2
    figure;
    for i_cond = 1:3
        
        % insert the topodata from each condition into a fieldtrip structure
        clear tmpdat TOPO
        tmpdat = DATA;
        
        cfg = [];
        cfg.latency = [1];
        cfg.trials = 1;
        tmpdat = ft_selectdata(cfg,tmpdat);
        
        cfg =[];
        TOPO = ft_timelockanalysis(cfg,tmpdat); % timelock
        
        TOPO.avg = squeeze(mean(allsbs_BMAT(i_cond,i_HF,:,plotlag1:plotlag2),4)); % replace by real data avg
        
        % ft_timelock that structure in the desired interval
        cfg = [];
        cfg.layout =  'elec1005.lay';
        cfg.colorbar = 'yes';
        cfg.parameter =  'avg';
        cfg.comment = 'no';
        cfg.zlim =  [-0.01 0.01];%[-0.05 0.05];%
        cfg.style = 'straight';
        cfg.marker = 'off';
        cfg.maskstyle='saturation';
        % cfg.gridscale=300;
        
        
        % plot
        subplot(3,1,i_cond)
        ft_topoplotER(cfg,TOPO);
        
        
    end
    
    annotation('textbox',[0.07 0.98 0.35 0.025],'String',...
        ['HF ' num2str(i_HF) ' TRF lags: ' num2str(plottimes(1)) ' - ' num2str(plottimes(2)) ' s'],'LineStyle','no');
    
   %  print('-dpdf',[PicDir filesep 'EEGII_TRF_topo_HF' num2str(i_HF) '_' num2str(plottimes(1)) ' - ' num2str(plottimes(2))   '.pdf'], '-painters')% PicDir filesep
    
end

%% compute correlation index

% datacond is the condition where the original EEG comes from
% predcond (the 3rd dimension of CORR_MAT is the condition from which the
% model was estimated

for i_sb = 1:size(CORR_MAT,1)
    for i_datacond = 1:size(CORR_MAT,2)
        for i_trial =   1: size(CORR_MAT{i_sb,i_datacond,1},1)
            
            % one value per channel
            corr1 = CORR_MAT{i_sb,i_datacond,1}(i_trial,:);
            corr3 = CORR_MAT{i_sb,i_datacond,3}(i_trial,:);
           
            ind_tmp = robust_index(corr1,corr3);
            
            CORR_IND{i_sb,i_datacond}(i_trial,:) = ind_tmp;
            
        end
        % avg over trials
        avg_CORR_IND(i_sb,i_datacond,:) = squeeze(mean(CORR_IND{i_sb,i_datacond},1));
    end
end

% add boxplot per condition
figure();hold on;
thischan = 'Fz';

plotchan = find(strcmp(DATA.label,thischan));
plot([1 2 3],mean(avg_CORR_IND(:,:,plotchan),1),...
        'Color',[0 0 0],'LineWidth',1);
    
for i_sb = 1:size(avg_CORR_IND,1)
    plot([1 2 3],avg_CORR_IND(i_sb,:,plotchan),'LineWidth',0.5,'Color',[0.9 0.9 0.9]);
end

for i_cond = 1:3
    plot(i_cond,avg_CORR_IND(:,i_cond,plotchan),'Marker','*','Color',[0.8 0.8 0.8]);
    plot(i_cond,mean(avg_CORR_IND(:,i_cond,plotchan),1),...
        'Marker','*','Color',cond_colors(i_cond,:),'LineWidth',2);
end

ylim([-.04 .03]);
xlim([0.75 3.25]);
hline(0,'k');

xlabel(['data cond']);
ylabel(['robust index'])
title(['correlation index (model 1 - 3) ' thischan])

% print('-dpdf',[PicDir filesep 'EEGII_TRF_2HFs_CorrInd_' thischan '.pdf'], '-painters')% PicDir filesep

%% plot topos of CorrInd
figure;
for i_cond = 1:3
    
    % insert the topodata from each condition into a fieldtrip structure
    clear tmpdat TOPO
    tmpdat = DATA;
    
    cfg = [];
    cfg.latency = [1];
    cfg.trials = 1;
    tmpdat = ft_selectdata(cfg,tmpdat);
    
    cfg =[];
    TOPO = ft_timelockanalysis(cfg,tmpdat); % timelock
    
    TOPO.avg = squeeze(mean(avg_CORR_IND(:,i_cond,:)));
    
    % ft_timelock that structure in the desired interval
    cfg = [];
    cfg.layout =  'elec1005.lay';
    cfg.colorbar = 'yes';
    cfg.parameter =  'avg';
    cfg.comment = 'no';
    cfg.zlim =  [-0.004 0.004]; %'maxabs';%
    cfg.style = 'straight';
    cfg.marker = 'off';
    cfg.maskstyle='saturation';
    % cfg.gridscale=300;
    
    
    % plot
    subplot(3,1,i_cond)
    ft_topoplotER(cfg,TOPO);
    
    
end

%     annotation('textbox',[0.07 0.98 0.35 0.025],'String',...
%         ['HF ' num2str(i_HF) ' TRF lags: ' num2str(plottimes(1)) ' - ' num2str(plottimes(2)) ' s'],'LineStyle','no');
%
% print('-dpdf',[PicDir filesep 'EEGII_TRF_2HFs_CorrInd_Topos.pdf'], '-painters')% PicDir filesep

%% compute running average of correlations over trials

colors = parula(4);
colors(3,:) = [];

maxtrials = 200; % maximal number of trials per cond
corrmat_trials_smooth = nan(numel(sbs),3,3,maxtrials,61);
figure();

% make matrix in which trials are concatenated
for i_sb = 1:numel(sbs)
    for i_cond = 1:3
        for pred_cond = 1:3
            ntrials = size(CORR_MAT{i_sb,i_cond,pred_cond},1);
            
            mean_CORR_MAT(i_sb,i_cond,pred_cond,:) = squeeze(nanmean(CORR_MAT{i_sb,i_cond,pred_cond},1));
            
            tmpdat = CORR_MAT{i_sb,i_cond,pred_cond};
            
            %             figure(i_sb + 100);
            %             subplot(1,3,i_cond);hold on;
            %             plot(1:size(tmpdat,1),tmpdat(:,plotchan),'color',colors(i_HF,:));
            %
            
            for i_trial = 8:size(CORR_MAT{i_sb,i_cond,pred_cond},1)-7
                % running avg over 15 trials
                tmpdat_smooth =  squeeze(nanmean(tmpdat(i_trial-7:i_trial+7,:),1));
                corrmat_trials_smooth(i_sb,i_cond,pred_cond,i_trial,:) = tmpdat_smooth;
            end
            subplot(1,3,i_cond);hold on;
            plotdat = squeeze(corrmat_trials_smooth(i_sb,i_cond,pred_cond,:,plotchan));
            plot(1:size(plotdat,1),plotdat,'color',colors(pred_cond,:),'LineWidth',1.5);
            ylim([-1 1])
            
            clear tmpdat;clear tmpdat_smooth;
        end
        
        
    end
end

% avg and sd
mean_corrmat_trials_smooth = squeeze(nanmean(corrmat_trials_smooth,1));
sd_corrmat_trials_smooth = squeeze(nanstd(corrmat_trials_smooth,1))./sqrt(24);


%% plot CORR for single subjects

thischan = 'Fz';
plotchan = find(strcmp(DATA.label,thischan));

figure(101+1);clf;figure(101+2);clf;figure(101+3);clf;
for i_sb = 1:numel(sbs)
    
    for i_cond = 1:3
        figure(101+i_cond); %subplot(6,4,i_sb)
        plot(squeeze(corrmat_trials_smooth(i_sb,i_cond,1,:,plotchan)),'color',cond_colors(1,:),'LineWidth',2) ; hold all;
        plot(squeeze(corrmat_trials_smooth(i_sb,i_cond,2,:,plotchan)),'color',cond_colors(2,:),'LineWidth',2) ; hold all;
        plot(squeeze(corrmat_trials_smooth(i_sb,i_cond,3,:,plotchan)),'color',cond_colors(3,:),'LineWidth',2) ; hold all;
        
        if i_sb == 1
            title(['cond' num2str(i_cond)])
        end
        ylim([-0.5 .5]);
        hline(0,'k');
    end
    
    % vline(condborders_ss(1),'k');
    % vline(condborders_ss(2),'k');
    % vline(condborders_ss(3),'k');
    if i_sb == 1
        legend({'predcond 1','predcond 2','predcond 3'});
    end
    
end
% % print -depsc mTRF_500_CORR_runavg.eps -painters

%% plot Correlations

thischan = 'Fz';
plotchan = find(strcmp(DATA.label,thischan));

figure(201+1);clf;
for i_cond =  1:3
    subplot(3,1,i_cond)
    
    cond_ix = find(~isnan(mean_corrmat_trials_smooth(i_cond,1,:,plotchan)));
    
    plot(cond_ix,squeeze(mean_corrmat_trials_smooth(i_cond,1,cond_ix,plotchan)),'color',cond_colors(1,:),'LineWidth',2) ; hold all;
    plot(cond_ix,squeeze(mean_corrmat_trials_smooth(i_cond,2,cond_ix,plotchan)),'color',cond_colors(2,:),'LineWidth',2) ; hold all;
    plot(cond_ix,squeeze(mean_corrmat_trials_smooth(i_cond,3,cond_ix,plotchan)),'color',cond_colors(3,:),'LineWidth',2) ; hold all;
    
    %     shadedErrorBar(cond_ix,squeeze(mean_corrmat_trials_smooth(i_cond,1,cond_ix,plotchan))',...
    %         squeeze(sd_corrmat_trials_smooth(i_cond,1,cond_ix,plotchan))',{'color',colors(1,:)},.5);
    %
    %     shadedErrorBar(cond_ix,squeeze(mean_corrmat_trials_smooth(i_cond,2,cond_ix,plotchan)),...
    %         squeeze(sd_corrmat_trials_smooth(i_cond,2,cond_ix,plotchan)),{'color',colors(2,:)},.5);
    %
    ylim([0 .4]);
    hline(0,'k');
    legend({'predcond1','predcond2','predcond3'});
    
    title(['correlations per HF channel:  Cond ' num2str(i_cond) ' ' thischan ' lambda: ' num2str(lambda)]);
end

% print('-dpdf',[PicDir 'EEGII_TRF_CORR' thischan  '.pdf'], '-painters')% PicDir filesep

%% add boxplot per condition

thischan = 'Fz';
plotchan = find(strcmp(DATA.label,thischan));

figure();
% extract correlations 
for i_sb = 1:24 % per sb
    for i_datacond = 1:3 % data condition
        for i_modcond = 1:3 % model condition
        mean_corr(i_sb,i_datacond,i_modcond) = squeeze(mean(CORR_MAT{i_sb,i_datacond,i_modcond}(:,plotchan),1));
        end
    end
end

for i_datacond = 1:3
    subplot(1,3,i_datacond)
    boxplot(squeeze(mean_corr(:,i_datacond,:)),'plotstyle','compact',...
        'symbol','k.','positions',[1 2 3],'colors',cond_colors,...
        'medianstyle','line');
    
    hline(0,'k');
    ylim([-.1  .3])
    
    grid on;
    title(['data cond: ' num2str(i_datacond)])
end
% make median lines black and big
set(findobj(gcf,'Tag','Median'),'LineWidth',2);

% make outlier dots gray and big
set(findobj(gcf,'Tag','Outliers'),'MarkerEdgeColor',[0.4 0.4 0.4],'MarkerSize',5);

% print('-dpdf',[PicDir filesep 'EEGII_TRF_Corr_BOX_' thischan '.pdf'], '-painters')% PicDir filesep

%% 45Grad Plot

% https://anneurai.net/2016/06/13/prettier-plots-in-matlab/
figure;

for i_datacond = 1:3
subplot(1,3,i_datacond)
% set the same data range on both axes
scatterHistDiff(squeeze(mean_corr(:,i_datacond,1)), squeeze(mean_corr(:,i_datacond,3)));
xlabel('Cond 1'); ylabel('Cond 3');
xlim([0 0.3]);ylim([0 0.3])
end

% print('-dpdf',[PicDir 'CorrInd_45deg.pdf'])% PicDir filesep



% print('-dpdf',[PicDir 'AudSens_ALLSBS_45deg_' num2str(size(DATA,2)) 'SBS_THRESH.pdf'])% PicDir filesep



%% plot predicted EEG

% choose one channel
thischan = 'Fz';
plotchan = find(strcmp(DATA.label,thischan));

clear condEEG condEEG_all

% loop over sbs and conds
for i_sb = 1:numel(sbs)
    for i_cond = 1:3
        for i_predcond = 1:3
            % extract data, nanmean over trials (nans exist because of unequal trial durations)
            tmp = squeeze(nanmean(predEEG{i_sb,i_cond,i_predcond},1));
%             tmp = tmp(plotchan,:);
%             tmp = tmp(find(~isnan(tmp)));

            % write in a matrix, using only the above defined channel
            condEEG(i_sb,i_cond,i_predcond,:) = tmp(plotchan,:);
        end
    end
end

% avg over participants
condEEG_all = squeeze(mean(condEEG,1));
SE_condEEG_all = squeeze(std(condEEG,1))./sqrt(numel(sbs));

%% plot pred EEG
figure;

for i_cond = 1%:3 
    % subplot(1,3,i_cond);hold on;
        for i_predcond = 1:3
        plot(Tvec,squeeze(condEEG_all(i_cond,i_predcond,:)),...
            'color',cond_colors(i_predcond,:),...
        'LineWidth',1.5);   hold on;
        end
        hline(0,'k');
        ylim([-.25 .25]);
        title(['datacond ' num2str(i_cond)]);
end

  for i_predcond = 1:3 % i_HF = 1:2
        shadedErrorBar(Tvec,squeeze(condEEG_all(i_cond,i_predcond,:)),squeeze(SE_condEEG_all(i_cond,i_predcond,:)),...
            {'color',cond_colors(i_predcond,:)},.5);
  end

% aesthetics
    set( gca                       , ...
        'FontName'   , 'Helvetica' ,...
        'FontSize'   , 8 );
    
    set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.02 .02] , ...
        'XMinorTick'  , 'off'      , ...
        'YMinorTick'  , 'off'      , ...
        'YGrid'       , 'off'      , ...
        'XGrid'       , 'off'      , ...
        'XColor'      , [0 0 0], ...
        'YColor'      , [0 0 0], ...
        'YTick'       , -.25: .05 : .25, ...
        'LineWidth'   , 0.5         );

    title(['predicted EEG ' thischan])
print('-dpdf',[PicDir filesep 'EEGII_TRF_predEEG_' thischan '.pdf'], '-painters')% PicDir filesep

%% plot orig EEG

% choose one channel
thischan = 'Fz';
plotchan = find(strcmp(DATA.label,thischan));

clear condEEG condEEG_all

% loop over sbs and conds
for i_sb = 1:numel(sbs)
    for i_cond = 1:3
            % extract data, nanmean over trials (nans exist because of unequal trial durations)
            tmp = origEEG{i_sb,i_cond};
            zero_ind = find(tmp == 0);
            tmp(zero_ind) = NaN;
            
            condEEG_orig(i_sb,i_cond,:) = nanmean(tmp(:,plotchan,:),1);
        end

end

% avg over participants
condEEG_orig_all = squeeze(nanmean(condEEG_orig,1));
SE_condEEG_orig_all = squeeze(nanstd(condEEG_orig,[],1))./sqrt(numel(sbs));

%% plot
figure;

for i_cond = 1:3 
    % subplot(1,3,i_cond);hold on;
        for i_predcond = 1:3
        plot(Tvec,squeeze(condEEG_orig_all(i_cond,:)),...
            'color',cond_colors(i_cond,:),...
        'LineWidth',1.5);   hold on;
        end
        hline(0,'k');
        
        title(['datacond ' num2str(i_cond)]);
end

for i_cond = 1:3 % i_HF = 1:2
        shadedErrorBar(Tvec,squeeze(condEEG_orig_all(i_cond,:)),squeeze(SE_condEEG_orig_all(i_cond,:)),...
            {'color',cond_colors(i_cond,:)},.5);
end
ylim([-.8 .4]);
% aesthetics
    set( gca                       , ...
        'FontName'   , 'Helvetica' ,...
        'FontSize'   , 8 );
    
    set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.02 .02] , ...
        'XMinorTick'  , 'off'      , ...
        'YMinorTick'  , 'off'      , ...
        'YGrid'       , 'off'      , ...
        'XGrid'       , 'off'      , ...
        'XColor'      , [0 0 0], ...
        'YColor'      , [0 0 0], ...
        'YTick'       , -.8: .1 : .4, ...
        'LineWidth'   , 0.5         );


    title(['original EEG ' thischan])
print('-dpdf',[PicDir filesep 'EEGII_TRF_origEEG_' thischan '.pdf'], '-painters')% PicDir filesep

%% plot example trials - realEEG
figure;

thistrial = 27; % chose a random trial

for i_cond = 1:3 
    subplot(3,1,i_cond);hold on;
        for i_predcond = 1:3
        plot(Tvec,squeeze(origEEG{1,i_cond}(thistrial,plotchan,:)),...
            'color',cond_colors(i_cond,:),...
        'LineWidth',1.5);   hold on;
        end
        hline(0,'k');
        ylim([-4 4]);
        xlim([.5 3.5]);
        title(['datacond ' num2str(i_cond)]);


% aesthetics
    set( gca                       , ...
        'FontName'   , 'Helvetica' ,...
        'FontSize'   , 8 );
    
    set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.01 .01] , ...
        'XMinorTick'  , 'off'      , ...
        'YMinorTick'  , 'off'      , ...
        'YGrid'       , 'off'      , ...
        'XGrid'       , 'off'      , ...
        'YTick'       , -4: 1 : 4, ...
        'LineWidth'   , 0.75         );

    title(['original EEG ' thischan])
    
    end
print('-dpdf',[PicDir filesep 'EEGII_TRF_origEEG_' thischan 'exampleTrials.pdf'], '-painters')% PicDir filesep

%% plot example trials - PredEEG

for i_cond = 1%:3 % only matters which model is taken
    figure(i_cond)

        for i_predcond = 1:3
            subplot(3,1,i_predcond);hold on
            
        plot(Tvec,squeeze(predEEG{1,i_cond,i_predcond}(thistrial,plotchan,:)),...
            'color',cond_colors(i_predcond,:),...
        'LineWidth',1.5);   hold on;
    hline(0,'k');
       
       
        ylim([-.4 .4]);
        xlim([.5 3.5]);
        title(['datacond ' num2str(i_cond)]);
% aesthetics
    set( gca                       , ...
        'FontName'   , 'Helvetica' ,...
        'FontSize'   , 8 );
    
    set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.01 .01] , ...
        'XMinorTick'  , 'off'      , ...
        'YMinorTick'  , 'off'      , ...
        'YGrid'       , 'off'      , ...
        'XGrid'       , 'off'      , ...
        'YTick'       , -.4: .1 : .4, ...
        'LineWidth'   , 0.5         );

    title(['pred EEG ' thischan])
      end
end

print('-dpdf',[PicDir filesep 'EEGII_TRF_predEEG_' thischan 'exampleTrials.pdf'], '-painters')% PicDir filesep

%% mean of correlations
for i_sb = 1:size(CORR_MAT,1)
    for i_datacond = 1:size(CORR_MAT,2)
        for i_modelcond = 1:size(CORR_MAT,3)
        meancorr(i_sb,i_datacond,i_modelcond,:) = mean(CORR_MAT{i_sb,i_datacond,i_modelcond},1);      
        end
    end
end

bigmean_corr = mean(mean(mean(meancorr(:,:,plotchan))));

