function [sourcedata] = EEGII_SourceLoc(i_sb,sbs)

% clear all;
% clc; close all;
% 
% %% Directories
% % load the path where fieldtrip is located
% addpath('/home/herbst/MATLAB_Toolboxes/fieldtrip-20160620/'); % using the newer FT version!
% addpath('/home/herbst/MATLAB_Toolboxes/shadedErrorBar');
% ft_defaults
% 
% % load TRF functions
% addpath('/home/herbst/MATLAB_Toolboxes/mTRF_1.3');
% 
rootDir = '/run/user/1023/gvfs/smb-share:server=storage.ipsy1.uni-luebeck.de,share=ipsy1/Users/herbst/DisTime_EEGII/';
% 
rawDir = [rootDir '/raw/'];
preprocDir = [rootDir '/preproc/'];
sourceDir = '/home/herbst/DisTime_EEGII_SourceDir'; %[rootDir '/source/'];
% 
PicDir = '/home/herbst/DisTime_EEGII_TRF_PICS/MatlabOutput/';
% 
% sbs = dir([rawDir '*.cnt']);
lock = 'cross';

%% Go Source Space

GRID_RES = 10; % GRID_RES = 10mm

% load standard MRI image and BEM (from ~Fieldtrip/template/headmodel)
load('standard_mri.mat');
load('standard_bem.mat');

% Load Electrode Layout-file
elec = ft_read_sens('standard_1005.elc'); % elec1005.lay

%% Load Data of first participant to get Channellabels (DATA)

% load raw DATA for each SB
[dum SB] =  fileparts(sbs(i_sb).name);
disp(['loading subject ' SB '...']);
load([preprocDir filesep SB 'preproc_complete_' lock 'lock_HP_minphase']);

DATA = DATA_clean; clear DATA_clean;

% Rereference to average of all Channels
cfg=[];
cfg.reref = 'yes';
cfg.refchannel = 'all';
DATA = ft_preprocessing(cfg,DATA);

% Get the right channels
elec_indx = ismember(elec.label,DATA.label);
elec.chanpos(~elec_indx,:) = [];
elec.elecpos(~elec_indx,:) = [];
elec.label(~elec_indx) = [];

% sanity reasons: bring elec field in same order as labels
for e=1:size(DATA.label,1);
    indx=ismember(elec.label,DATA.label(e));
    elec_new.chanpos(e,:)=elec.chanpos(indx,:);
    elec_new.elecpos(e,:)=elec.elecpos(indx,:);
end

elec_new.label = DATA.label;
elec = elec_new;

% check the match of head and electrodes
figure;
ft_plot_mesh(vol.bnd(1), 'edgecolor','none','facealpha',0.8,'facecolor',[0.6 0.6 0.8]);
hold on
ft_plot_sens(elec,'style', 'sk','label','on');

% prepare leadfield
cfg = [];
cfg.grid.resolution = GRID_RES; % Resolution in mm
cfg.headmodel = vol;
cfg.elec = elec;
cfg.reducerank = 3;
cfg.channel = DATA.label;
lf = ft_prepare_leadfield(cfg);

VoxPos = lf.pos; % Voxel positions
InsPos = lf.inside; % Mask Inside

save([sourceDir filesep 'InsPos'],'InsPos');
save([sourceDir filesep 'VoxPos'],'VoxPos');

%% Now loop over all SBS

% for each subject, build commonfilter lcmv filter based on
% all trials a task time and ai_sbly it to single trial data

% for i_sb = 1 %: size(sbs,1)
    
    clear commonfilter_tlock DATA clean tlock
    
    clc
    display(['Working on subject ' num2str(i_sb)])
    clear clean sampleinfo
    
    % load raw DATA for each SB
    [dum SB] =  fileparts(sbs(i_sb).name);
    disp(['loading subject ' SB '...']);
    load([preprocDir filesep SB 'preproc_complete_' lock 'lock_HP_minphase']);
    
    DATA = DATA_clean; clear DATA_clean;
    
    % make average reference
    cfg=[];
    cfg.reref = 'yes';
    cfg.refchannel = 'all';
    DATA = ft_preprocessing(cfg,DATA);
    
    % calculate timelock
    cfg                   = [];
    cfg.covariance        = 'yes';
    cfg.channel           = 'all';
    cfg.covariancewindow  = 'all';
    % cfg.vartrllength      = 2; % variable triallength; default = 0
    TlockData             = ft_timelockanalysis(cfg, DATA);
    
    % build commonfilter
    cfg              = [];
    cfg.method       = 'lcmv';
    cfg.headmodel = vol;
    cfg.grid = lf;
    cfg.elec = elec;
    cfg.lcmv.keepfilter  = 'yes';
    cfg.lcmv.fixedori    = 'no';
    commonfilter_tlock   = ft_sourceanalysis(cfg, TlockData);
    
    if i_sb == 1;
        save('commonfilter_dummy','commonfilter_tlock')
    end
    
    % source-project single trials
    clear sourcedata
    sourcedata.trial = cell(1, length(DATA.trial));
    sourcedata.label = cell(1,1);
    sourcedata.trialinfo = DATA.trialinfo;
    sourcedata.fsample = DATA.fsample;
    sourcedata.time = DATA.time;
    
    % get all filters
    ALLFILTERS(:,:,:,i_sb) = permute(squeeze(cat(3,commonfilter_tlock.avg.filter{commonfilter_tlock.inside})),[3 2 1]);
    
    % get labels right
    InVox=commonfilter_tlock.inside;
    sourcedata.label = [];
    for vx=1:length(find(InVox==1));
        sourcedata.label{vx,1} = strcat('VirtCH', num2str(vx));
    end
    
    % source-project single trials
    for tr = 1:length(DATA.trial);
        display(['Projecting trial ' num2str(tr)])
        clear projected
        for dir = 1:3
            sourcedata.trial{tr}(:,:,dir) = ALLFILTERS(:,:,dir,i_sb)*DATA.trial{tr};
        end
    end
    
    % Do a PCA on different XYZ-Timecourses and extract first Component
    disp('PCA...')
    for v = 1:size(sourcedata.trial{tr},1)
        
        CAT_DATA = [];
        
        for tr = 1:size(sourcedata.trial,2)
            CAT_DATA = cat(2,sourcedata.trial{tr}(v,:,:));
        end
        PCA(:,:,v) = pca(squeeze(CAT_DATA));
        clear CAT_DATA
    end
    
    for tr = 1:size(sourcedata.trial,2)
        for v = 1:size(sourcedata.trial{tr},1)
            SOURCE_DATA(v,:) = (squeeze(sourcedata.trial{tr}(v,:,:))*PCA(:,1,v))';
        end
        sourcedata.trial{tr} = SOURCE_DATA;
        clear SOURCE_DATA
    end
    
    sourcedata.dimord = 'rpt_chan_time';
    
%     tic
%     save([sourceDir filesep SB 'Sourcedata_' lock '_locked'], 'sourcedata', '-v7.3');
%     toc
% end


