
% Script calculates a forward encoding model on time domain EEG DATA
% (see Lalor 2006, 2009);


% Sophie Herbst, Feb. 2016
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%
clear all;
clc; close all;

%% Directories
% load the path where fieldtrip is located
addpath('/home/herbst/MATLAB_Toolboxes/fieldtrip-20170501/'); % using the newer FT version!
addpath('/home/herbst/MATLAB_Toolboxes/shadedErrorBar');
ft_defaults

% load TRF functions
addpath('/home/herbst/MATLAB_Toolboxes/mTRF_1.3');

rootDir = '/run/user/1023/gvfs/smb-share:server=storage.ipsy1.uni-luebeck.de,share=ipsy1/Users/herbst/DisTime_EEGII/';

rawDir = [rootDir '/raw/'];
preprocDir = [rootDir '/preproc/'];
sourceDir = '/home/herbst/DisTime_EEGII_SourceDir'; %[rootDir '/source/'];

PicDir = '/home/herbst/DisTime_EEGII_TRF_PICS/MatlabOutput/';%% Parameters

run_model = 1; % run mTRF or just load the saved data
check_plots = 1; % make single subject plots

% lags for the TRF;
tau = [-200  600];

% timevector for the lags (used for plotting)
tlags = tau(1)/1000:1/200:tau(2)/1000;
nlags = size(tlags,2);

% ridge parameter for the TRF
lambda = 4;

% epoch time-locked to cross/cue or tone
lock = 'cross';

% latency for ft_selectdata (epoching from cue)
latency =[0 3.5];

% use only trials that have minimally this foreperiod duration
minFP = 0.65;

% take DATA only from that timepoint (postcue); avoid mixing in cue-resonse
startLAT = .5;

% subjects
sbs = dir([rawDir '*.cnt']);

% define one channel for plotting
channame = 'VirtCH1';

% colors for the plots
cond_colors = [253,184,99; 178,171,210; 94,60,153];
cond_colors = cond_colors./255;

%% load and plot the hazard Functions:

% load([rootDir filesep 'preproc_notes' filesep  'sHF4Reg_long0.mat']); % subjective (with Shadlen's smoothing factor)
load([preprocDir filesep  'EEGII_HF4Reg_long0.mat']);

% plot the HFs
figure; hold on;
for i_cond = 1:size(HF_time_matrix_long,2)
    subplot(3,1,i_cond);
    plot(HF_time_matrix_long(i_cond).HF_time(:,1),HF_time_matrix_long(i_cond).HF_time(:,2),...
        'color',cond_colors(i_cond,:),'LineWidth',1);
    title(['condition ' num2str(i_cond)])
    ylabel('hazard');
end
xlabel('time [s]');

% filter HFs

% use only 2 HFs: from conditions 1 & 3
condHF1 = HF_time_matrix_long(1).HF_time(:,2);
condHF3 = HF_time_matrix_long(3).HF_time(:,2);
condHF3 = condHF3-condHF1;
condHF3(find(condHF3<0))= 0;

condHF = [condHF1 condHF3];

[b,a] = butter(6,[25/(200/2)],'low'); % 1.arg = order, 2. = cutoff-freq/(fs/2), 3. low or highpass
condHF = filtfilt(b,a,condHF); % filter twopass

subplot(3,1,1);hold on;
plot(HF_time_matrix_long(1).HF_time(:,1),condHF(:,1),...
        'color',cond_colors(1,:),'LineWidth',1);
    
subplot(3,1,3);hold on;
plot(HF_time_matrix_long(3).HF_time(:,1),condHF(:,2),...
        'color',cond_colors(i_cond,:),'LineWidth',1);
    
%% initialize MATRICES sbs x conditions x HF

% B_MAT= cell(size(sbs,1),3); % Matrix for the regression weights, sbs x conds
% const_MAT = cell(size(sbs,1),3); % Matrix for the regression constant, sbs x conds
% origEEG = cell(size(sbs,1),3); % Matrix for original data; does not differ between 2 HFs
% STIM_MAT = cell(size(sbs,1),3); % Matrix for Stimuli (HF),sbs x conds

% predEEG = cell(size(sbs,1),3); % Matrix for predicted EEG data
% CORR_MAT = cell(size(sbs,1),3); % Matrix for correlations
% CORR_MAT_index = cell(size(sbs,1),3); % Matrix for correlation indices

FP_MAT = cell(size(sbs,1),3); % note the FPs for each trial

% Matrix for trial-averaged reg weights
% avgB_MAT = NaN(numel(sbs),3,2,61,nlags);  % sbs x conds x HF x channels x lags

%% start loading DATA

if run_model
    for i_sb = 1 : size(sbs,1)
        
       % load raw DATA for each SB
        [dum SB] =  fileparts(sbs(i_sb).name);
        disp(['preparing subject ' SB '...']);
        
        % run the sourceloc script to get the data
        tic;
        [sourcedata] = EEGII_SourceLoc(i_sb,sbs);
        toc;
        disp(['Getting sourcedata took ' num2str(toc/60) ' min']);
        DATA = sourcedata; % clear sourcedata
        
        plotchan = find(strcmp(DATA.label,channame));
        
        %% LP filter the data
        
        cfg = [];
        cfg.lpfilter = 'yes';
        cfg.lpfilttype = 'but'; %'firws';
        
        cfg.lpfilord = 6;
        
        cfg.plotfiltresp = 'no';
        cfg.lpfiltdir = 'twopass'; %'onepass-zerophase';
        
        cfg.lpfreq   = 25; %8% % low pass frequency
        cfg.lpfiltdf = 1; % transition band witdth
        
        DATA_filt = ft_preprocessing(cfg,DATA);
        
        
        % check effect of filtering
        if check_plots

            tmptime = DATA.time{1};
            
            cfg = [];
            DATA_avg = ft_timelockanalysis(cfg,DATA);
            DATA_filt_avg = ft_timelockanalysis(cfg,DATA_filt);
            
            tmpdat = DATA_avg.avg;
            tmpdat_filt = DATA_filt_avg.avg;
            
            figure();
            plot(tmptime,tmpdat(plotchan,:)); hold all;
            plot(tmptime,tmpdat_filt(plotchan,:));
            
            legend({'unfiltered', 'filtered'});
            title (['SB ' SB ' channel channame' ])
            
            clear DATA_avg DATA_filt_avg tmpdat tmpdat_filt
        end
        
        DATA = DATA_filt; clear DATA_filt;
        fs = round(DATA.fsample); % round because in some sbs fs = 200.00 and that causes prblms with mTRF
        
        %% select DATA at the defined latencies
        
        cfg = [];
        cfg.latency = latency;
        DATA = ft_selectdata(cfg,DATA);
        
        Tvec = DATA.time{1}; % the data time vector
        
        % for TRF only data from 500ms after cue onset will be used
        % to remove visual onset ERP
        startIX = nearest(Tvec,startLAT); % same for all trials
        % endIX is defined in each trial, as the onset of the target tone
        
        
        %% loop over conditions
        for i_cond = 1:3
            disp(['cond ' num2str(i_cond)]);
            
            
            %% prepare condition DATA
            
            clear condDATA;
            
            % select all trials from the condition and with FP >= minFP
            cfg = [];
            cfg.trials = find(DATA.trialinfo(:,1) == i_cond & DATA.trialinfo(:,3) >= minFP);
            condDATA = ft_selectdata(cfg,DATA);
            
            
%             %% initialize subjects's matrix for regression weights: trials x HF x channels x lags
%             
%             B_MAT{i_sb,i_cond} = nan(size(condDATA.trial,2),2,61,nlags);
%             const_MAT{i_sb,i_cond} = nan(size(condDATA.trial,2),2,61);
%            
%             % STIM_MAT{i_sb,i_cond} = nan(size(condDATA.trial,2),size(condDATA.trial{1},2),2); % trials x TP x HF
%             % predEEG{i_sb,i_cond,i_HF} = nan(size(condDATA.trial,2),size(condDATA.trial{1},1),size(condDATA.trial{1},2)); % trials x chan x TP
%             % origEEG{i_sb,i_cond}  = nan(size(condDATA.trial,2),size(condDATA.trial{1},1),size(condDATA.trial{1},2)); % trials x chan x TP
%                 
            %% loop over trials
            for i_trial = 1:size(condDATA.trial,2)

                % get FP on each trial
                trialFP = condDATA.trialinfo(i_trial,3);
                ixFP = nearest(Tvec,trialFP); % find the closest sampling point
                endFP = 3.5;               
                ixendFP = nearest(Tvec,endFP);
                
                % time vector for the trial DATA
                trial_Tvec = Tvec(startIX:ixendFP); 
                
                %% take the data from this trial and cut relevant times
                trialDAT = condDATA.trial{i_trial}(:,startIX:ixendFP); % and cut out the relevant time interval
                
                % cut the HF to the same lentght
                trialHF = condHF(startIX:ixendFP,:);
                
                %% zscore both timeseries, make time 1. dimension
                
                % normalize HF
                ztrialHF1 = trialHF(:,1) ./ max(trialHF(:,1));
                ztrialHF2 = trialHF(:,2) ./ max(trialHF(:,2));
                ztrialHF = [ztrialHF1 ztrialHF2];
                clear ztrialHF1 ztrialHF2
                
                % zscore trial Data over time
                ztrialDAT = zscore(trialDAT');
                
                ztrialDAT((ixFP-startIX)+1:end,:) = 0;
                
%                 figure;
%                 plot(trial_Tvec, ztrialHF(:,1)); hold all;
%                 plot(trial_Tvec, ztrialHF(:,2)); hold all;
%                 plot(trial_Tvec, ztrialDAT(:,plotchan));
%                 legend({'HF1','HF3', 'EEG data'});
%                 % hline(0,'k');
%                 title(['Example HF and EEG DATA, 1 Trial']);
                
               % write DATA and stim (HF) in big matrices
               %  STIM_MAT{i_sb,i_cond}(i_trial,startIX:ixFP,:) = ztrialHF;
               %  origEEG{i_sb,i_cond}(i_trial,:,startIX:ixFP)  = ztrialDAT';
                
               %% this is the TRF
               [X,T,const] =  mTRFtrain(ztrialHF,ztrialDAT,fs,0,tau(1), tau(2),lambda);
               % dir    - direction of mapping (forward==0, backward==1)
               
               
               % write the betas into a matrix, trial x HF x chan x time
               B_MAT(i_trial,:,:,:) = permute(X,[1,3,2]);
            end
            
               % SB_B_MAT(i_cond,:,:,:) = squeeze(mean(B_MAT,1));
               SB_B_MAT_trials(:,i_cond,:,:,:) = B_MAT;
              
               
               %plot single TRF
               % plot(T,squeeze(X(:,:,plotchan))); % plot single trial mTRF
               % legend({'HF1','HF2'})
               % hline(0, 'k');
               % title(['TRF SB ' SB ' lambda: ' num2str(lambda) '-- cond' num2str(i_cond) ' --FP: ' num2str(trialFP)]);
               % xlabel('TRF lag [s]')
               
        end
             % save([sourceDir filesep 'RES_EEGII_TRF_pred2HFs_SB' num2str(i_sb) '_source_longHF_peakonly'],'SB_B_MAT')  ;
             save([sourceDir filesep 'RES_EEGII_TRF_pred2HFs_SB' num2str(i_sb) '_source_longHF_peakonly_singletrials'],'SB_B_MAT_trials')  ;
             
             % clear SB_B_MAT
             clear SB_B_MAT_trials
            
    end
end