require('ggplot2')
require('plyr')
require('dplyr')
require("Hmisc");
require("lme4")
require('lmerTest')
require("gridExtra")
require('effects')
require('languageR')
require('statmod')

doplots = 1

################################################################
## load DATA from textfile
################################################################
# DisTime: Tracking 85%, FP-sd on logscale, SBS 17 - ..
Project <- "DisTime"
#Exp <- "DisTime_LEARN_NOISE" # NoMem"  # NoMem" # 2Tones" #LEARN"
Exp <- "DisTime_EEGII" 
# DistTime_2Tones; DATA_newestsbs
# DistTime_NoMem; DATA20_sbs
# DistTime_LEARN; _DATA_EEG_18sbs


currwd <- getwd()

## working directory
#wd <- paste0("/Users/Sophie/Documents/PostDoc/EXPERIMENTS/DisTime_DATA/")
wd <- paste0("/Users/Sophie/ownCloud/PROJECT_DisTime/ALL_DisTime_DATA/")

# wd <- paste0("/home/raid3/sherbst/Dropbox/PROJECT_DisTime/")
#wd <- paste0("D:/Dropbox/PROJECT_DisTime/")
#wd <- paste0("/Users/Sophie/Dropbox/Project_DisTime/")
setwd(wd)

## load data from txt
file <- paste0(getwd(), "/DATA_DisTime_EEGII_24sbs.txt") #  15sbs

#file <- paste0(getwd(), "/" , Exp, "_DATA/", Exp, "_DATA_22sbs.txt") #  15sbs
##file <- paste0(getwd(), "/", Project,"_DATA/", Project,"_DATA.txt")
DATA <- read.table(file, header = TRUE)

subjects <- unique(DATA$sbname)

# DATA5<-DATA[DATA$sbname == subjects[5],]

## recode condition as factor
DATA$FPst <- as.numeric(as.character(DATA$FPst)) # DATA$FPst cond
DATA$oldcond <- as.factor(DATA$cond)
sec_cond <- DATA$cond[DATA$cond > 3]
DATA$cond[DATA$cond > 3] <- sec_cond - 3
DATA$logcond <- log(DATA$FPst)
DATA$cond <- as.factor(DATA$cond)
# ################################################################
# ## plot the FPs used

BREAKS <- sort(unique(DATA$FP))
n <- length(BREAKS)
S <- BREAKS[n] - BREAKS[n-1]
BREAKS[n+1] <- BREAKS[n] + S

plot.new()
fig <- ggplot(data = DATA[DATA$sbname == subjects[1],], aes(x = FP, color = cond)) # [DATA$sbname == subjects[1],]
fig <- fig + geom_histogram(breaks = BREAKS)
fig <- fig + facet_grid(.~ cond)  #~ sbname
fig <- fig + geom_vline(xintercept = 0,linetype="dotted")
fig <- fig + theme(text = element_text(size = 16))
fig <- fig + theme(axis.text = element_text(size = 14, colour = "black"))
fig

plot.new()
fig2 <- ggplot(data = DATA, aes(x = FP , y = ToneFreq, color = cond)) 
fig2 <- fig2 + geom_point()
fig2 <- fig2 + facet_grid(.~ sbname)  #~ sbname
fig2 <- fig2 + geom_vline(xintercept = 0,linetype="dotted")
fig2

plot.new()
fig3 <- ggplot(data = DATA, aes(x = trial , y = Rep.RT, color = cond)) 
fig3 <- fig3 + geom_point()
fig3 <- fig3 + facet_grid(.~ sbname)  #~ sbname
fig3 <- fig3 + geom_vline(xintercept = 0,linetype="dotted")
fig3

################################################################
## add blockcount, recode RT
################################################################


## write mini-block variable into DATA
trialsperblock <- 0
DATA$condblock <- 0

conds <- sort(unique(DATA$oldcond))

for (c in 1:length(conds)){
  condDATA <- DATA[DATA$oldcond == conds[c],]
  trialsperblock[c] <- nrow(condDATA)/(length(subjects)*3)
  remove(condDATA) 

for (s in 1:length(subjects)){
DATA$condblock[DATA$oldcond==conds[c] & DATA$sbname == subjects[s]] <- sort(rep(1:3,trialsperblock[c]))
}
}

## condorder
DATA$condorder <- 0
DATA$condorderF <- NaN
for (s in 1:length(subjects)){
  conds <- unique(DATA$oldcond[DATA$sbname == subjects[s]])
  condcount <- 0
 
  for (c in conds){  
  condcount <- condcount + 1
  condDATA <- DATA[DATA$oldcond == conds[c],]
  trialsperblock[c] <- nrow(condDATA)/(length(subjects)*6)
  remove(condDATA) 

DATA$condorder[DATA$oldcond==conds[condcount] & DATA$sbname == subjects[s]] <- condcount
  }
}

DATA$condorderF <- as.factor(DATA$condorder)

avgOrder <- ddply(DATA, .(cond), 
                  summarise,
                       mOrder = mean(condorder))


## ztrial
DATA$ztrial<- scale(DATA$trial)

## logRT
DATA$logRT <- log(1000 * DATA$Rep.RT)
DATA$invRT <- as.double(dinvgauss(DATA$Rep.RT))

## compute RT-1
DATA$logRTm1 <- 0
T <- 1:nrow(DATA)
X <- DATA$logRT[T-1]
DATA$logRTm1[2:length(T)] <- X
DATA$logRTm1[1] <- DATA$logRTm1[2]

for (t in 2:nrow(DATA)-1){ # first trial for each SB is replaced by value for second trial
 if(DATA$sbname[t] != DATA$sbname[t+1]) {
   DATA$logRTm1[t+1] <- DATA$logRTm1[t+2]}
}


## computeFP-1
DATA$FPm1 <- 0
T <- 1:nrow(DATA)
X <- DATA$FP[T-1]

DATA$FPm1[2:length(T)] <- X
DATA$FPm1[1] <- DATA$FPm1[2]

for (t in 2:nrow(DATA)-1){ # first trial for each SB is replaced by value for second trial
  if(DATA$sbname[t] != DATA$sbname[t+1]) {
    DATA$FPm1[t+1] <- DATA$FPm1[t+2]}
}

DATA$FPdiff <- DATA$FP - DATA$FPm1

## compute zFP
## (number of standard deviations away from the mean minus the delay (for each condition)

for (i in sort(unique(DATA$cond))) {
  DATA$zFP[DATA$cond == i] <- (DATA$FP[DATA$cond == i] - (mean(DATA$FP[DATA$cond == i])))/DATA$FPst[DATA$cond == i]
}


################################################################
## recode Rep.type to 1/0
################################################################

DATA$HiLo <- NaN
DATA$HiLo[DATA$Rep.type == 1] <- 0
DATA$HiLo[DATA$Rep.type == 2] <- 1

################################################################
## count & remove misses
################################################################
num_miss <- 0

for (s in 1:length(subjects)){
  num_miss[s]<-length(which(is.na(DATA$Rep.type[DATA$sbname == subjects[s]])))
}

which(is.na(DATA$Rep.type))
DATA <- DATA[complete.cases(DATA$Rep.type), ]
unique(DATA$HiLo)

DATA$HiLo<-as.numeric(DATA$HiLo)

################################################################
## recode frequency rel to ind
################################################################

freqvec <- c(-5,-4,-3,-2,-1,1,2,3,4,5)
DATA$relFreq <- 0
for (s in 1:length(subjects)){
  freqs <- sort(unique(DATA$ToneFreq[DATA$sbname == subjects[s]]))
  for (f in 1:length(freqs)){
  DATA$relFreq[DATA$ToneFreq == freqs[f]] <- freqvec[f]
  }
}
DATA$relFreq <- as.numeric(DATA$relFreq)
DATA$relFreqF <- as.factor(DATA$relFreq)

################################################################
## remove missings and outliers
################################################################
plot.new()
fig <- ggplot(data = DATA, aes(x = trial, y = Rep.RT, color = sbname)) 
fig <- fig + geom_point() 
#fig <- fig + geom_hline(yintercept= c(M_RT + 2.5*SD_RT, M_RT - 2.5*SD_RT),linetype="dotted")
fig <- fig + geom_hline(yintercept=0)
fig


## mark outliers per SB
numout <- 0
out_trials <- {}
DATA$out <- 0

for (s in 1:length(subjects)){
  M_RT <- mean(DATA$logRT[DATA$sbname == subjects[s]], na.rm = TRUE)
  SD_RT <- sd(DATA$logRT[DATA$sbname == subjects[s]], na.rm = TRUE)
  out_RT <-  (DATA$logRT[DATA$sbname == subjects[s]] < M_RT - 2.5*SD_RT ) | (DATA$logRT[DATA$sbname == subjects[s]] > log(2000)) # M_RT + 2.5*SD_RT)  
  DATA$out[DATA$sbname == subjects[s]] <- out_RT
  numout[s]<-length(which(out_RT == TRUE))
}

## remove the outliers
DATA$Rep.type[DATA$out == 1] <- NaN
DATA <- DATA[complete.cases(DATA$Rep.type), ]

plot.new()
fig <- ggplot(data = DATA, aes(x = trial, y = logRT, color = sbname)) 
fig <- fig + geom_point() 
#fig <- fig + geom_hline(yintercept= c(M_RT + 2.5*SD_RT, M_RT - 2.5*SD_RT),linetype="dotted")
# fig <- fig + geom_hline(yintercept=0)
fig

# add avg performance as factor (needed for driftdiff)
avgDATA <- ddply(DATA, .(sbname), # FP, StandFreq,
                 summarise, 
                 RT = mean(Rep.RT),
                 corr = mean(Rep.corr),
                 conf = mean(Rep.conf))

DATA$avgperf <- 0
sbnames <- unique(DATA$sbname)

for (n in 1:length(unique(DATA$sbname))){
  DATA$avgperf[DATA$sbname == sbnames[n]] <- avgDATA$corr[avgDATA$sbname == sbnames[n]]
}

## compute relRT: substract the mean RT of each participant from all RTs
DATA$relRT_log <- 0
for (s in 1:length(subjects)){
  M_RT <- mean(DATA$logRT[DATA$sbname == subjects[s]], na.rm = TRUE)
  DATA$relRT_log[DATA$sbname == subjects[s]] <- DATA$logRT[DATA$sbname == subjects[s]] - M_RT
}

## bin FP
breaks <- sort(unique(DATA$FP[DATA$cond == 3]))
breaks <- c(0,breaks,3.1)
DATA$binFP <- .bincode(DATA$FP,breaks)


# remove 1. block and wrong trials
#DATA <- DATA[DATA$condblock > 1,]
DATA1 <- DATA[DATA$condblock > 1,]
DATAc <- DATA[DATA$Rep.corr == 1,]
DATAc1 <- DATA1[DATA1$Rep.corr == 1,]

## RTs by subject
# RT Distributions, sb-outliers removed
P1 <- ggplot(DATA,aes(x=Rep.RT,col=sbname)) + 
  geom_density(binwidth=.01) 
# coord_cartesian(xlim=c(0,3))
P2 <- ggplot(DATA,aes(x=logRT,col=sbname)) + 
  geom_density(binwidth=.01) 
# coord_cartesian(xlim=c(0,3))
P3 <- ggplot(DATA,aes(x=relRT_log,col=sbname)) + 
   geom_density(binwidth=.01) 
#coord_cartesian(xlim=c(0,3))
grid.arrange(P1, P2, P3) #, P3

# make midFPDATA
FPs <- sort(unique(DATA$FP))
numFPs <- length(FPs)

# bin several intermediate FP
midFPs <- FPs[((numFPs/2)) : ((numFPs/2)+2)]
#midFPs <- sort(unique(DATA$FP[DATA$cond==0.1]))
midFP_DATA <- DATA[DATA$FP >= midFPs[1] & DATA$FP <= midFPs[length(midFPs)] ,]


## test for normality
f = function(dfr) return(shapiro.test(dfr$logRT)$p.value)
p = as.vector(by(DATA, DATA$sbname, f))
names(p) = levels(DATA$sbname)
names(p[p < 0.05])

# autocorrelation
acf.fnc(DATA, group = 'sbname', time = 'trial', x = 'logRT', plot = TRUE)

# RT variation across trials
P<- 
  ggplot(data=DATA, aes(x=trial, y=Rep.RT))  + # ,color = cond)
  geom_point(shape = 1)+
  geom_smooth(method=lm) +
  facet_grid(.~ sbname) 
P

P<- 
  ggplot(data=DATA, aes(x=trial, y=Rep.RT, group = cond, color = cond))  + # ,color = cond)
  geom_point(shape = 1)+
  geom_smooth(method=lm)
  # facet_grid(.~ sbname) 
P


################################################################
##DURTrials
################################################################
allFPs <- sort(unique(DATA$FP))
meanFP = round(mean(allFPs),digits=1) # round because otherwise there is a minmal difference at the 7th decimal

DurDATA <- DATA[DATA$DurTrial == 1,]
DurDATA$DURcorr <- NA

for (t in 1:dim(DurDATA)[1]){
  if (!is.nan(DurDATA$Rep.dur[t])){
  # short interval
  if (DurDATA$FP[t] < meanFP) {
    if (DurDATA$Rep.dur[t] == 1) {
      DurDATA$DURcorr[t] = 1}
    else if (DurDATA$Rep.dur[t] == 2){
      DurDATA$DURcorr[t] = 0}}
  
  # long interval
  else if (DurDATA$FP[t] > meanFP) {
    if (DurDATA$Rep.dur[t] == 2) {
      DurDATA$DURcorr[t] = 1}
    else if (DurDATA$Rep.dur[t] == 1){
      DurDATA$DURcorr[t] = 0}}
}}

meanDURcorr <- mean(DurDATA$DURcorr, na.rm=TRUE)

DurPlot<- ggplot(data=DurDATA, aes(x=FP, y=DURcorr),  main = "Duration Trials")  +
  #stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line") # + 
 #  facet_grid(.~ sbname) 
DurPlot



################################################################
## plot & explore the factors of interest
################################################################
if (doplots == 1) {
avgDATA <- ddply(DATA, .(sbname), # FP, StandFreq,
                 summarise, 
                 RT = mean(Rep.RT),
                 corr = mean(Rep.corr),
                 conf = mean(Rep.conf))

# add avg performance as factor
DATA$avgperf <- 0
sbnames <- unique(DATA$sbname)

for (n in 1:length(unique(DATA$sbname))){
  DATA$avgperf[DATA$sbname == sbnames[n]] <- avgDATA$corr[avgDATA$sbname == sbnames[n]]
}

################################################################
# performance across blocks per condition

Pperf_avg<- ggplot(data=DATA, aes(x=cond, y=Rep.corr, group=cond, color = cond),  main = "Performance")  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  # stat_summary(fun.data = "mean_cl_boot", geom="line") + 
  facet_grid(.~ sbname) +
  geom_hline(yintercept=0.75) 
Pperf_avg

################################################################
# plot RT as a function of (z)FP and condition


PFP1<-  
  ggplot(data=DATA1, aes(x=FP, y=logRT, group=oldcond, color = oldcond))  + # , fill = cond
 #  stat_summary(fun.data = "mean_cl_boot", conf.int=0.95, geom = "ribbon",alpha = 0.2, colour=NA)+
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line")  #+
  # facet_grid(.~ sbname) 
 # geom_hline(yintercept=0)
 # coord_cartesian(ylim=c(5.5,7.5))
# PFP1

PFP2<- 
  ggplot(data=DATA1, aes(x=FP, y=Rep.corr, group=oldcond, color = oldcond))  +
 
  # stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line") #+
 #facet_grid(.~ sbname) 
  # geom_hline(yintercept=0)
# PFP2

PFP3<- 
  ggplot(data=DATA1, aes(x=FP, y=Rep.conf, group=oldcond, color = oldcond))  +
  # stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line")  # +
 # facet_grid(.~ sbname) 
 # geom_hline(yintercept=0)

grid.arrange(PFP1,PFP2,PFP3, main ="all FPs")

# plot only avg RT with confidence IV
PFP_RT<-  
  ggplot(data=DATA, aes(x=binFP, y=logRT, group=cond, color = cond,fill = cond))  + # , fill = cond
  stat_summary(fun.data = "mean_cl_boot", conf.int=0.95, geom = "ribbon",alpha = 0.2, colour=NA)+
  stat_summary(fun.data = "mean_cl_boot", geom="point")  +
  stat_summary(fun.data = "mean_cl_boot", geom="line")  #+
  # facet_grid(.~ sbname) 
PFP_RT

# plot only avg acc with confidence IV
PFP_corr<-  
  ggplot(data=DATA1, aes(x=binFP, y=Rep.corr, group=cond, color = cond,fill = cond))  + # , fill = cond
  stat_summary(fun.data = "mean_cl_boot", conf.int=0.95, geom = "ribbon",alpha = 0.2, colour=NA)+
  stat_summary(fun.data = "mean_cl_boot", geom="point")  +
  stat_summary(fun.data = "mean_cl_boot", geom="line")  #+
# facet_grid(.~ sbname) 
PFP_corr

################################################################
# plot RT as a function of Frequency and cond
PInt1<- 
  ggplot(data=DATA, aes(x=relFreq, y=logRT, group=cond, color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line") 
  #facet_grid(.~ sbname, scales = "free_x") #+


PInt2<- 
  ggplot(data=DATA, aes(x=relFreq, y=Rep.type, group=cond, color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line") 
  #facet_grid(.~ sbname, scales = "free_x") 


PInt3<- 
  ggplot(data=DATA, aes(x=relFreq, y=Rep.conf, group=cond, color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line")  
  #facet_grid(.~ sbname, scales = "free_x") 

grid.arrange(PInt1,PInt2,PInt3, main ="X = Frequency [Hz]")

################################################################
# plot RT avg at intermediate FPs

PintFP1<- 
  ggplot(data=midFP_DATA, aes(x=condorder, y=logRT, color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point")+
 facet_grid(.~ sbname, scales = "free_y") 
  # coord_cartesian(ylim=c(6.5,7))

PintFP2<-
  ggplot(data=midFP_DATA, aes(x=condorder, y=Rep.corr, color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  facet_grid(.~ sbname, scales = "free_y") 

PintFP3<- 
  ggplot(data=midFP_DATA, aes(x=condorder, y=Rep.conf, color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  facet_grid(.~ sbname, scales = "free_y") 
  
grid.arrange(PintFP1,PintFP2,PintFP3, main ="intermediate FP")


################################################################
# plot RT avg at all FPs
PavgFP1<- 
  ggplot(data=DATA, aes(x=cond, y=Rep.RT, color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line") 
#  facet_grid(.~ sbname) 
# PavgFP1

PavgFP2<- 
  ggplot(data=DATA, aes(x=cond, y=Rep.corr, color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line") 
 # facet_grid(.~ sbname) 
# P2
PavgFP3<- 
  ggplot(data=DATA, aes(x=cond, y=Rep.conf,color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line") 
 # facet_grid(.~ sbname) 

grid.arrange(PavgFP1,PavgFP2,PavgFP3, main ="avg of all FP")


# plot conditions versus condorder
Pcond<- 
  ggplot(data=DATA, aes(x=condorder, y=Rep.RT, color = cond))  +
  stat_summary(fun.data = "mean_cl_boot") + #, conf.int=0.95, geom = "errorbar"
  stat_summary(fun.data = "mean_cl_boot", geom="point") +
  stat_summary(fun.data = "mean_cl_boot", geom="line") +
  facet_grid(.~ sbname, scales = "free_y") 
Pcond


# single subject data per trial

S <- subjects[1]

PsS<- 
  ggplot(data=DATA[DATA$sbname == S,], aes(x=trial, y=Rep.RT, color = cond))  +
  geom_point() + geom_line() +
  geom_point(aes(x=trial, y=FP),color = "black")
PsS


rand_SS<- 
  ggplot(data=DATA, aes(x=trial, y=FP, color = sbname))  +
  geom_point()
rand_SS

}
################################################################


################################################################
## LMEs
################################################################


# BOXPLOTS
Pbox_intFP <- 
  ggplot(data=midFP_DATA, aes(x=cond, y=logRT,color = cond)) +
  geom_boxplot(notch = TRUE) +
  ggtitle('intermediate FPs')
# geom_boxplot(data=midFP_DATA, aes(x=cond, y=logRT, color = sbname)) 
# geom_jitter(data=midFP_DATA, aes(x=cond, y=logRT, color = sbname))
Pbox_intFP

Pbox_allFP <- 
  ggplot(data=DATA1, aes(x=cond, y=logRT,color = cond)) +
  geom_boxplot(notch = TRUE) +
  ggtitle('all FPs')
# geom_boxplot(data=midFP_DATA, aes(x=cond, y=logRT, color = sbname)) 
# geom_jitter(data=midFP_DATA, aes(x=cond, y=logRT, color = sbname))
Pbox_allFP

# grid.arrange(Pbox_intFP, Pbox_allFP)


################################################################
##  calculate models
################################################################

modDAT <- DATA

# NULL Model
LME0 <- lmer(formula = logRT ~ 1 + (1|sbname), data = modDAT) #REML = FALSE
cor(fitted(LME0), modDAT$logRT)^2

# LME1 <- lmer(formula = logRT ~ FPst + (1|sbname), data = modDAT) 
# LME2 <- lmer(formula = logRT ~ poly(FPst,2) + (1|sbname), data = modDAT) 
# LME3 <- lmer(formula = logRT ~ FP + (1|sbname), data = modDAT) 
# anova(LME0,LME1,LME2)
# anova(LME2)
# plot(effect("poly(FPst, 2)",LME2)) 

LME1 <- lmer(formula = logRT ~ FP + (1|sbname), data = modDAT) 
LME2 <- lmer(formula = logRT ~ FP + cond + (1|sbname), data = modDAT) 
LME3 <- lmer(formula = logRT ~ FP * cond + (1|sbname), data = modDAT) 
LME4 <- lmer(formula = logRT ~ poly(FP,2)+ (1|sbname)  , data = modDAT) # *FPdiff*relFreq  #poly(x,2); x + I(x^2)
LME5 <- lmer(formula = logRT ~ poly(FP,2) + cond +  (1|sbname)  , data = modDAT) 
LME6 <- lmer(formula = logRT ~ poly(FP,2) * cond +  (1|sbname)  , data = modDAT)
LME7 <- lmer(formula = logRT ~ poly(FP,2) + (1+cond|sbname)  , data = modDAT)
LME8 <- lmer(formula = logRT ~ poly(FP,2) + cond +  (1+cond|sbname)  , data = modDAT)
LME9 <- lmer(formula = logRT ~ poly(FP,2) * cond + ztrial +(1+cond|sbname)  , data = modDAT)
LME10 <- lmer(formula = logRT ~ poly(FP,2) * cond * ztrial +(1+cond|sbname)  , data = modDAT)
anova(LME0,LME1, LME2, LME3, LME4,LME5,LME6)#,LME7,LME8,LME9,LME10


# # Add all the factors of interest
# LME1 <- lmer(formula = logRT ~ FP + (1|sbname), data = modDAT) 
# LME2 <- lmer(formula = logRT ~ I(FP^2)+ (1|sbname)  , data = modDAT) # *FPdiff*relFreq  #poly(x,2); x + I(x^2)
# LME3 <- lmer(formula = logRT ~ FP + I(FP^2) +  (1|sbname)  , data = modDAT) 
# LME4 <- lmer(formula = logRT ~ FP + I(FP^2) +  cond  + (1|sbname)  , data = modDAT) 
# LME5 <- lmer(formula = logRT ~ FP + I(FP^2) * cond + (1|sbname)  , data = modDAT)
# LME6 <- lmer(formula = logRT ~ FP * I(FP^2) * cond + (1|sbname)  , data = modDAT)
# 
# LME7 <- lmer(formula = logRT ~ ztrial + (1|sbname)  , data = modDAT)
# LME8 <- lmer(formula = logRT ~ ztrial + FP + I(FP^2) +(1|sbname)  , data = modDAT)
# LME9 <- lmer(formula = logRT ~ FP + I(FP^2) + cond *  ztrial  + (1|sbname)  , data = modDAT)
# LME10 <- lmer(formula = logRT ~ FP + I(FP^2) * cond *  ztrial  + (1|sbname)  , data = modDAT)
# 
# anova(LME0,LME1, LME2, LME3, LME4, LME5, LME6, LME7 , LME8 , LME9 , LME10 ) # ,LME6

LME <- LME1

anova(LME)
summary(LME)

plot(effect("cond",LME)) 
plot(effect("FP",LME)) 
plot(effect("FP:cond ",LME),multiline = TRUE) 
plot(effect("poly(FP,2)",LME)) 
plot(effect("ztrial",LME)) 
plot(effect("poly(FP,2):cond ",LME),multiline = TRUE) 
plot(effect("poly(FP,2):ztrial ",LME),multiline = TRUE) 
dotplot(ranef(LME, condVar=TRUE)) 

LME1 <- lmer(formula = logRT ~ relFreq + (1|sbname)  , data = modDAT) # *FPdiff*relFreq  #poly(x,2); x + I(x^2)
LME2 <- lmer(formula = logRT ~ relFreq + poly(FP,2) + (1|sbname)  , data = modDAT) 
LME3 <- lmer(formula = logRT ~ relFreq * poly(FP,2) + (1|sbname)  , data = modDAT) 
# LME4<- lmer(formula = logRT ~ relFreq + poly(FP,2) + cond + (1|sbname)  , data = modDAT) 
LME5 <- lmer(formula = logRT ~ poly(FP,2)*relFreq  + cond + (1|sbname)  , data = modDAT) 
LME6 <- lmer(formula = logRT ~ relFreq * poly(FP,2) * cond + (1|sbname)  , data = modDAT) 
LME7 <- lmer(formula = logRT ~ relFreq + poly(FP,2) * cond + (1|sbname)  , data = modDAT) 
anova(LME0,LME1, LME2, LME3, LME5,LME6,LME7)

summary(LME5)



## fit single conditions
Rcond <- 0

#for (i_cond in 1:length(conds)){
i_cond <- 3
LME0 <- lmer(formula = logRT ~  (1|sbname)  , data = modDAT[modDAT$cond == i_cond,])
LME1 <- lmer(formula = logRT ~ FP+ (1|sbname)  , data = modDAT[modDAT$cond == i_cond,])
LME1p <- lmer(formula = logRT ~ poly(FP,2)+ (1|sbname), data = modDAT[modDAT$cond == i_cond,])
anova(LME0,LME1,LME1p)
LME <- LME1p

#Rcond[i_cond] <- cor(fitted(LME), modDAT$logRT[modDAT$cond == i_cond])^2
#}
Rcond

summary(LME)
plot(effect("FP",LME)) 
plot(effect("poly(FP, 2)",LME1p)) 


# # all Residuals 
plot(abs(scale(resid(LME))))
# # Residuals vs fitted
plot(LME,type=c("p","smooth")) ## fitted vs residual
# # or plot(MOD)
# # Normality
qqmath(LME,id=0.05)


LME <- LME3p

anova(LME)
ranef(LME)
dotplot(ranef(LME, condVar=TRUE)) 

plot(effect("cond",LME)) 
plot(effect("FPdiff",LME)) 
plot(effect("poly(FP, 2)",LME)) 
plot(effect("relFreq",LME)) 
plot(effect("poly(FP, 2):cond",LME),multiline = TRUE) 
plot(effect("poly(FP, 2):relFreq",LME4),multiline = TRUE) 


# ef <-effect("poly(FP,2):cond",LME1)
# summary(ef)
# x <- as.data.frame(ef)
# 
# 
# ggplot(x, aes(FP, fit, color = cond)) + #, color=Group 
#   geom_point() +
#   geom_line() 



# supermodel
# LME_sup <- lmer(formula = logRT ~ poly(FP,2)*cond*relFreq*ztrial + (1+ztrial|sbname) , data = DATAc, REML = FALSE) #REML = FALSE
# relFreq
#  


# Diagnostic Plots:

# # all Residuals 
plot(abs(scale(resid(LME))))
# # Residuals vs fitted
plot(LME,type=c("p","smooth")) ## fitted vs residual
# # or plot(MOD)

# # Normality
qqmath(LME,id=0.05)

# ?plot.merMod > Examples

### plot binned residuals
# http://stats.stackexchange.com/questions/63566/unexpected-residuals-plot-of-mixed-linear-model-using-lmer-lme4-package-in-r
# library(arm)
# par(bg="white", cex=1, las=1)
# binnedplot(predict(MOD), resid(MOD), cex.pts=1, col.int="black")

# use model criticism to remove outliers
DATA_modcrit = DATA[abs(scale(resid(LME))) < 2.5,]
LME_modcrit <- update(LME,data = DATA_modcrit) #REML = FALSE
LME_modcrit <- lmer(formula = logRT ~  poly(FP,2) * cond + (1|sbname)  , data = DATA_modcrit) 

# LME_modcrit <- lmer(formula = logRT ~ poly(FP,2)*cond*ztrial+ (1|sbname), data  = DATA_modcrit, REML = FALSE) #REML = FALSE
cor(fitted(LME_modcrit), DATA_modcrit$logRT)^2
summary(LME_modcrit)
anova(LME_modcrit)
plot(effect("poly(FP, 2):cond",LME_modcrit), multiline = TRUE) 

#####################################################
# GLMER
#####################################################

LME_corr <- glmer(formula = Rep.corr ~ relFreq*cond + (1|sbname) , data = DATA, family = binomial) #REML = FALSE
summary(LME_corr)

plot(effect("cond",LME_corr)) 
plot(effect("relFreq:cond",LME_corr),multiline = TRUE) 

LME_corr <- glmer(formula = HiLo ~ relFreq*cond + (1|sbname) , data = DATA, family = binomial) #REML = FALSE
summary(LME_corr)

plot(effect('cond',LME_corr,multiline = TRUE) )
plot(effect("relFreq:cond",LME_corr),multiline = TRUE) 

plotLMER.fnc(LME_corr, fun=plogis, addlines=TRUE, pred = 'relFreq')

plotLMER.fnc(LME_corr, fun=plogis, pred = 'relFreq',
             intr=list("cond", sort(unique(DATA$cond)), "mid"),
              addlines=TRUE)

plot(effect("relFreq:cond",LME_corr), multiline = TRUE) 

LME_corr0 <- glmer(formula = Rep.corr ~  (1|sbname) , data = modDAT, family = binomial) #REML = FALSE
LME_corr1 <- glmer(formula = Rep.corr ~ FP + (1|sbname) , data = modDAT, family = binomial) #REML = FALSE
LME_corr2 <- glmer(formula = Rep.corr ~ poly(FP,2)  + (1|sbname) , data = modDAT, family = binomial) #REML = FALSE
LME_corr3 <- glmer(formula = Rep.corr ~  cond +(1|sbname) , data = modDAT, family = binomial) #REML = FALSE
LME_corr4 <- glmer(formula = Rep.corr ~  FP + cond +(1|sbname) , data = modDAT, family = binomial) #REML = FALSE
LME_corr5 <- glmer(formula = Rep.corr ~  poly(FP,2)  + cond +(1|sbname) , data = modDAT, family = binomial) #REML = FALSE
LME_corr6 <- glmer(formula = Rep.corr ~  FP * cond +(1|sbname) , data = modDAT, family = binomial) #REML = FALSE
LME_corr7 <- glmer(formula = Rep.corr ~  poly(FP,2)  * cond +(1|sbname) , data = modDAT, family = binomial) #REML = FALSE

anova(LME_corr0,LME_corr1,LME_corr2,LME_corr3,LME_corr4,LME_corr5,LME_corr6,LME_corr7)

summary(LME_corr3)

plot(effect("cond",LME_corr3),multiline = TRUE) 

